require 'rubygems'
require 'bundler'

begin
  Bundler.setup(:default, :development)
rescue Bundler::BundlerError => e
  $stderr.puts e.message
  $stderr.puts "Run `bundle install` to install missing gems"
  exit e.status_code
end

require 'fakeweb'

class CachableKlass
  def self.cache_name
    'test'
  end

  def self.cache_version
    19871009
  end

  def self.cache_file(name, data="test")
    File.open("#{DistributedCache.config.cache_dir}/#{self.cache_name}/#{name}", 'wb+') { |f| f.write data }
  end

  def self.update_cache(manifeset)
    if manifeset.full?
      cache_file 'full1', 'test1'
      cache_file 'full2', 'test2'
      cache_file 'full3', 'test3'
    else
      cache_file 'partial1', '1'
      cache_file 'partial2', '2'
      cache_file 'full2', 'changed2'
    end
  end
end

BASE_TMP_DIR = "#{Dir.pwd}/tmp/rspec"

def configure_test_distributed_cache
  FileUtils.rm_rf BASE_TMP_DIR

  DistributedCache.configure do |config|
    config.file_servers = ['localhost']
    config.cache_dir = "#{BASE_TMP_DIR}/cache"
    config.bundle_dir = "#{BASE_TMP_DIR}/bundles"
  end
end

RSpec.configure do |config|
  config.before(:each) do
    FakeWeb.allow_net_connect = false
    FakeWeb.clean_registry
  end
end

$LOAD_PATH.unshift(File.dirname(__FILE__))
require 'distributed_cache'
